
/* Generated data (by pika-mkenums) */

#include "stamp-widgets-enums.h"
#include "config.h"
#include <gtk/gtk.h>
#include "libpikabase/pikabase.h"
#include "widgets-enums.h"
#include "pika-intl.h"

/* enumerations from "widgets-enums.h" */
GType
pika_active_color_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_ACTIVE_COLOR_FOREGROUND, "PIKA_ACTIVE_COLOR_FOREGROUND", "foreground" },
    { PIKA_ACTIVE_COLOR_BACKGROUND, "PIKA_ACTIVE_COLOR_BACKGROUND", "background" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_ACTIVE_COLOR_FOREGROUND, NC_("active-color", "Foreground"), NULL },
    { PIKA_ACTIVE_COLOR_BACKGROUND, NC_("active-color", "Background"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaActiveColor", values);
      pika_type_set_translation_context (type, "active-color");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_circle_background_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_CIRCLE_BACKGROUND_PLAIN, "PIKA_CIRCLE_BACKGROUND_PLAIN", "plain" },
    { PIKA_CIRCLE_BACKGROUND_HSV, "PIKA_CIRCLE_BACKGROUND_HSV", "hsv" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_CIRCLE_BACKGROUND_PLAIN, NC_("circle-background", "Plain"), NULL },
    { PIKA_CIRCLE_BACKGROUND_HSV, NC_("circle-background", "HSV"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaCircleBackground", values);
      pika_type_set_translation_context (type, "circle-background");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_dialog_state_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_DIALOG_OK, "PIKA_COLOR_DIALOG_OK", "ok" },
    { PIKA_COLOR_DIALOG_CANCEL, "PIKA_COLOR_DIALOG_CANCEL", "cancel" },
    { PIKA_COLOR_DIALOG_UPDATE, "PIKA_COLOR_DIALOG_UPDATE", "update" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_DIALOG_OK, "PIKA_COLOR_DIALOG_OK", NULL },
    { PIKA_COLOR_DIALOG_CANCEL, "PIKA_COLOR_DIALOG_CANCEL", NULL },
    { PIKA_COLOR_DIALOG_UPDATE, "PIKA_COLOR_DIALOG_UPDATE", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorDialogState", values);
      pika_type_set_translation_context (type, "color-dialog-state");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_pick_target_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_PICK_TARGET_NONE, "PIKA_COLOR_PICK_TARGET_NONE", "none" },
    { PIKA_COLOR_PICK_TARGET_FOREGROUND, "PIKA_COLOR_PICK_TARGET_FOREGROUND", "foreground" },
    { PIKA_COLOR_PICK_TARGET_BACKGROUND, "PIKA_COLOR_PICK_TARGET_BACKGROUND", "background" },
    { PIKA_COLOR_PICK_TARGET_PALETTE, "PIKA_COLOR_PICK_TARGET_PALETTE", "palette" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_PICK_TARGET_NONE, NC_("color-pick-target", "Pick only"), NULL },
    { PIKA_COLOR_PICK_TARGET_FOREGROUND, NC_("color-pick-target", "Set foreground color"), NULL },
    { PIKA_COLOR_PICK_TARGET_BACKGROUND, NC_("color-pick-target", "Set background color"), NULL },
    { PIKA_COLOR_PICK_TARGET_PALETTE, NC_("color-pick-target", "Add to palette"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorPickTarget", values);
      pika_type_set_translation_context (type, "color-pick-target");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_color_pick_state_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_COLOR_PICK_STATE_START, "PIKA_COLOR_PICK_STATE_START", "start" },
    { PIKA_COLOR_PICK_STATE_UPDATE, "PIKA_COLOR_PICK_STATE_UPDATE", "update" },
    { PIKA_COLOR_PICK_STATE_END, "PIKA_COLOR_PICK_STATE_END", "end" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_COLOR_PICK_STATE_START, "PIKA_COLOR_PICK_STATE_START", NULL },
    { PIKA_COLOR_PICK_STATE_UPDATE, "PIKA_COLOR_PICK_STATE_UPDATE", NULL },
    { PIKA_COLOR_PICK_STATE_END, "PIKA_COLOR_PICK_STATE_END", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaColorPickState", values);
      pika_type_set_translation_context (type, "color-pick-state");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_histogram_scale_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_HISTOGRAM_SCALE_LINEAR, "PIKA_HISTOGRAM_SCALE_LINEAR", "linear" },
    { PIKA_HISTOGRAM_SCALE_LOGARITHMIC, "PIKA_HISTOGRAM_SCALE_LOGARITHMIC", "logarithmic" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_HISTOGRAM_SCALE_LINEAR, NC_("histogram-scale", "Linear histogram"), NULL },
    { PIKA_HISTOGRAM_SCALE_LOGARITHMIC, NC_("histogram-scale", "Logarithmic histogram"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaHistogramScale", values);
      pika_type_set_translation_context (type, "histogram-scale");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_tab_style_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TAB_STYLE_ICON, "PIKA_TAB_STYLE_ICON", "icon" },
    { PIKA_TAB_STYLE_PREVIEW, "PIKA_TAB_STYLE_PREVIEW", "preview" },
    { PIKA_TAB_STYLE_NAME, "PIKA_TAB_STYLE_NAME", "name" },
    { PIKA_TAB_STYLE_BLURB, "PIKA_TAB_STYLE_BLURB", "blurb" },
    { PIKA_TAB_STYLE_ICON_NAME, "PIKA_TAB_STYLE_ICON_NAME", "icon-name" },
    { PIKA_TAB_STYLE_ICON_BLURB, "PIKA_TAB_STYLE_ICON_BLURB", "icon-blurb" },
    { PIKA_TAB_STYLE_PREVIEW_NAME, "PIKA_TAB_STYLE_PREVIEW_NAME", "preview-name" },
    { PIKA_TAB_STYLE_PREVIEW_BLURB, "PIKA_TAB_STYLE_PREVIEW_BLURB", "preview-blurb" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TAB_STYLE_ICON, NC_("tab-style", "Icon"), NULL },
    { PIKA_TAB_STYLE_PREVIEW, NC_("tab-style", "Current status"), NULL },
    { PIKA_TAB_STYLE_NAME, NC_("tab-style", "Text"), NULL },
    { PIKA_TAB_STYLE_BLURB, NC_("tab-style", "Description"), NULL },
    { PIKA_TAB_STYLE_ICON_NAME, NC_("tab-style", "Icon & text"), NULL },
    { PIKA_TAB_STYLE_ICON_BLURB, NC_("tab-style", "Icon & desc"), NULL },
    { PIKA_TAB_STYLE_PREVIEW_NAME, NC_("tab-style", "Status & text"), NULL },
    { PIKA_TAB_STYLE_PREVIEW_BLURB, NC_("tab-style", "Status & desc"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaTabStyle", values);
      pika_type_set_translation_context (type, "tab-style");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_tag_entry_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_TAG_ENTRY_MODE_QUERY, "PIKA_TAG_ENTRY_MODE_QUERY", "query" },
    { PIKA_TAG_ENTRY_MODE_ASSIGN, "PIKA_TAG_ENTRY_MODE_ASSIGN", "assign" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_TAG_ENTRY_MODE_QUERY, "PIKA_TAG_ENTRY_MODE_QUERY", NULL },
    { PIKA_TAG_ENTRY_MODE_ASSIGN, "PIKA_TAG_ENTRY_MODE_ASSIGN", NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaTagEntryMode", values);
      pika_type_set_translation_context (type, "tag-entry-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}


/* Generated data ends here */

